@@ -1,7 +1,8 @@
 #!/bin/sh
+export PATH='/usr/obj/hs-HTTP-4000.2.10/bin:/usr/bin:/bin:/usr/sbin:/sbin:/usr/local/bin:/usr/local/bin:/usr/X11R6/bin'
 echo 'name: HTTP
-version: 4000.2.8
-id: HTTP-4000.2.8-f0521402a0b2a00514705f5569e76353
+version: 4000.2.10
+id: HTTP-4000.2.10-f899b20722d95264e2a176f9b134f446
 
 license: BSD3
 copyright:
@@ -51,25 +52,25 @@ exposed-modules: Network.BufferType Network.Stream
 hidden-modules: Network.HTTP.Base64 Network.HTTP.MD5Aux
                 Network.HTTP.Utils Paths_HTTP
 trusted: False
-import-dirs: /usr/local/lib/ghc/HTTP-4000.2.8
-library-dirs: /usr/local/lib/ghc/HTTP-4000.2.8
-hs-libraries: HSHTTP-4000.2.8
+import-dirs: /usr/local/lib/ghc/HTTP-4000.2.10
+library-dirs: /usr/local/lib/ghc/HTTP-4000.2.10
+hs-libraries: HSHTTP-4000.2.10
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: array-0.4.0.1-3b78425c10ff2dad7acf7e8c8ae014c3
-         base-4.6.0.1-03845c6da2a0b3b4d0d49cc26c0cd3c0
-         bytestring-0.10.0.2-9e8b487747800a4255d6ff7915c5210f
-         mtl-2.1.2-94c72af955e94b8d7b2f359dadd0cb62
-         network-2.4.1.2-2410fd33cfc22dd877d4b24516181434
-         old-time-1.1.0.1-029c40e673a46f6084b935f654a6fa28
-         parsec-3.1.3-8bc25b86282839a5b5fcb3c428bb3b9c
+depends: array-0.5.0.0-470385a50d2b78598af85cfe9d988e1b
+         base-4.7.0.2-e1c96ce41208f09c293083d78870d5a2
+         bytestring-0.10.4.0-84f2b632cefc94e5dfeafb660607fcbd
+         mtl-2.1.3.1-96f1a7910a7553352339ed05fb61c269
+         network-2.4.2.3-878f8bfcc369ed62265df39b168036b0
+         old-time-1.1.0.2-e3f776e97c1a6ff1770b04943a7ef7c6
+         parsec-3.1.5-7f6674da593b27c3fdd904274a0dcd1e
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-HTTP-4000.2.8/html/HTTP.haddock
-haddock-html: /usr/local/share/doc/hs-HTTP-4000.2.8/html
+haddock-interfaces: /usr/local/share/doc/hs-HTTP-4000.2.10/html/HTTP.haddock
+haddock-html: /usr/local/share/doc/hs-HTTP-4000.2.10/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
